@@ -3,7 +3,7 @@ package Net::Curl::Promiser;
 use strict;
 use warnings;
 
-our $VERSION = '0.14_01';
+our $VERSION = '0.15_01';
 
 =encoding utf-8
 
@@ -13,6 +13,12 @@ Net::Curl::Promiser - Asynchronous L<libcurl|https://curl.haxx.se/libcurl/>, the
 
 =head1 DESCRIPTION
 
+=begin html
+
+<a href='https://coveralls.io/github/FGasper/p5-Net-Curl-Promiser?branch=master'><img src='https://coveralls.io/repos/github/FGasper/p5-Net-Curl-Promiser/badge.svg?branch=master' alt='Coverage Status' /></a>
+
+=end html
+
 L<Net::Curl::Multi> is powerful but tricky to use: polling, callbacks,
 timers, etc. This module does all of that for you and puts a Promise
 interface on top of it, so asynchronous I/O becomes almost as simple as
@@ -77,6 +83,9 @@ each event interface.) These are kept separate to avoid circular references.
 
 use parent 'Net::Curl::Promiser::LeakDetector';
 
+# So that Net::Curl::Easy::Code’s overloading gets set up:
+use Net::Curl::Easy ();
+
 use Net::Curl::Multi ();
 
 use constant _DEBUG => 0;
